#!/usr/bin/python
#
# keyboard_models.py - keyboard model list
#
# Brent Fox <bfox@redhat.com>
# Mike Fulbright <msf@redhat.com>
# Jeremy Katz <katzj@redhat.com>
#
# Copyright 2002 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

from rhpl.translate import _, N_
import rhpl.translate as translate

translate.textdomain('rhpl')

def gkn(str):
    idx = str.find("|")
    if idx == -1:
        return str
    return str[idx + 1:]

class KeyboardModels:

    def get_models(self):
        return self.modelDict

    def __init__(self):
        # NOTE: to add a keyboard model to this dict, copy the comment
        # above all of them, and then the key should be the console layout
        # name.  val is [gkn(_('keyboard|Keyboard Name')), xlayout, kbmodel,
        # variant, options]
        self.modelDict = {
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ar-azerty'               : [gkn(_('keyboard|Arabic (azerty)')), 'us,ar(azerty)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'                 ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ar-azerty-digits'        : [gkn(_('keyboard|Arabic (azerty/digits)')), 'us,ar(azerty_digits)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ar-digits'               : [gkn(_('keyboard|Arabic (digits)')), 'us,ar(digits)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ar-qwerty'               : [gkn(_('keyboard|Arabic (qwerty)')), 'us,ar(qwerty)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ar-qwerty-digits'        : [gkn(_('keyboard|Arabic (qwerty/digits)')), 'us,ar(qwerty_digits)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'be-latin1'               : [gkn(_('keyboard|Belgian (be-latin1)')), 'be', 'pc105', '', ''                        ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ben'                      : [gkn(_('keyboard|Bengali (Inscript)')), 'us,ben', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ben-probhat'             : [gkn(_('keyboard|Bengali (Probhat)')), 'us,ben(probhat)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'bg'                      : [gkn(_('keyboard|Bulgarian')), 'us,bg', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'br-abnt2'                : [gkn(_('keyboard|Brazilian (ABNT2)')), 'br', 'abnt2', '', ''                          ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'cf'                      : [gkn(_('keyboard|French Canadian')), 'ca_enhanced', 'pc105', '', ''                   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'croat'                   : [gkn(_('keyboard|Croatian')), 'hr', 'pc105', '', '' ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'cz-us-qwertz'            : [gkn(_('keyboard|Czechoslovakian (qwertz)')), 'us,cz', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'cz-lat2'                 : [gkn(_('keyboard|Czechoslovakian')), 'cz_qwerty', 'pc105', '', ''                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'de'                      : [gkn(_('keyboard|German')), 'de', 'pc105', '', ''                                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'de-latin1'               : [gkn(_('keyboard|German (latin1)')), 'de', 'pc105', '', ''                            ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'de-latin1-nodeadkeys'    : [gkn(_('keyboard|German (latin1 w/ no deadkeys)')), 'de', 'pc105', 'nodeadkeys', ''   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'dev'                     : [gkn(_('keyboard|Devanagari (Inscript)')), 'us,dev', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'dvorak'                  : [gkn(_('keyboard|Dvorak')), 'dvorak', 'pc105', '', ''                                 ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'dk'                      : [gkn(_('keyboard|Danish')), 'dk', 'pc105', '', ''                                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'dk-latin1'               : [gkn(_('keyboard|Danish (latin1)')), 'dk', 'pc105', '', ''                            ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'es'                      : [gkn(_('keyboard|Spanish')), 'es', 'pc105', '', ''                                    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'et'                      : [gkn(_('keyboard|Estonian')), 'ee', 'pc105', '', ''                                   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fi'                      : [gkn(_('keyboard|Finnish')), 'fi', 'pc105', '', ''                                    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fi-latin1'               : [gkn(_('keyboard|Finnish (latin1)')), 'fi', 'pc105', '', ''                           ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fr'                      : [gkn(_('keyboard|French')), 'fr', 'pc105', '', ''                                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fr-latin9'               : [gkn(_('keyboard|French (latin9)')), 'fr-latin9', 'pc105', '', ''                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fr-latin1'               : [gkn(_('keyboard|French (latin1)')), 'fr', 'pc105', '', ''                            ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fr-pc'                   : [gkn(_('keyboard|French (pc)')), 'fr', 'pc105', '', ''                                ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fr_CH'                   : [gkn(_('keyboard|Swiss French')), 'fr_CH', 'pc105', '', ''                            ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'fr_CH-latin1'            : [gkn(_('keyboard|Swiss French (latin1)')), 'fr_CH', 'pc105', '', ''                   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'gr'                      : [gkn(_('keyboard|Greek')), 'us,el', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'guj'                     : [gkn(_('keyboard|Gujarati (Inscript)')), 'us,guj', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'gur'                     : [gkn(_('keyboard|Punjabi (Inscript)')), 'us,gur', 'pc105', '', ''                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'hu'                      : [gkn(_('keyboard|Hungarian')), 'hu', 'pc105', '', ''                                  ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'hu101'                   : [gkn(_('keyboard|Hungarian (101 key)')), 'hu_qwerty', 'pc105', '', ''                 ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'is-latin1'               : [gkn(_('keyboard|Icelandic')), 'is', 'pc105', '', ''                                  ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'it'                      : [gkn(_('keyboard|Italian')), 'it', 'pc105', '', ''                                    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'it-ibm'                  : [gkn(_('keyboard|Italian (IBM)')), 'it', 'pc105', '', ''                              ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'it2'                     : [gkn(_('keyboard|Italian (it2)')), 'it', 'pc105', '', ''                              ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'jp106'                   : [gkn(_('keyboard|Japanese')), 'jp', 'jp106', '', ''                                   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'us'               : [gkn(_('keyboard|Korean')), 'us', 'pc105', '', ''                             ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'la-latin1'               : [gkn(_('keyboard|Latin American')), 'la', 'pc105', '', ''                             ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'mk-utf'                  : [gkn(_('keyboard|Macedonian')), 'us,mk', 'pc105', '','grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'nl'                      : [gkn(_('keyboard|Dutch')), 'nl', 'pc105', '', ''                                  ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'no'                      : [gkn(_('keyboard|Norwegian')), 'no', 'pc105', '', ''                                  ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'pl'                      : [gkn(_('keyboard|Polish')), 'pl', 'pc105', '', ''                                     ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'pt-latin1'               : [gkn(_('keyboard|Portuguese')), 'pt', 'pc105', '', ''                                 ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ro_win'                  : [gkn(_('keyboard|Romanian')), 'ro', 'pc105', '', ''                                   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ru'                      : [gkn(_('keyboard|Russian')), 'us,ru', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'            ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ru-cp1251'               : [gkn(_('keyboard|Russian (cp1251)')), 'us,ru', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ru-ms'                   : [gkn(_('keyboard|Russian (Microsoft)')), 'us,ru', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ru1'                     : [gkn(_('keyboard|Russian (ru1)')), 'us,ru', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'      ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ru2'                     : [gkn(_('keyboard|Russian (ru2)')), 'us,ru', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'      ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ru_win'                  : [gkn(_('keyboard|Russian (win)')), 'us,ru', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'      ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'sv-latin1'               : [gkn(_('keyboard|Swedish')), 'se', 'pc105', '', ''                                    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'sg'                      : [gkn(_('keyboard|Swiss German')), 'de_CH', 'pc105', '', ''                            ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'sg-latin1'               : [gkn(_('keyboard|Swiss German (latin1)')), 'de_CH', 'pc105', '', ''                   ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'sk-qwerty'               : [gkn(_('keyboard|Slovakian')), 'sk_qwerty', 'pc105', '', ''                           ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'slovene'                 : [gkn(_('keyboard|Slovenian')), 'si', 'pc105', '', ''                                  ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'tml-inscript'            : [gkn(_('keyboard|Tamil (Inscript)')), 'us,tml(INSCRIPT)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'tml-uni'                 : [gkn(_('keyboard|Tamil (Typewriter)')), 'us,tml(UNI)', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'trq'                     : [gkn(_('keyboard|Turkish')), 'tr', 'pc105', '', ''                                    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'uk'                      : [gkn(_('keyboard|United Kingdom')), 'gb', 'pc105', '', ''                             ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'ua-utf'                  : [gkn(_('keyboard|Ukrainian')), 'us,ua', 'pc105', '', 'grp:shift_toggle,grp_led:scroll'],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'us-acentos'              : [gkn(_('keyboard|U.S. International')), 'us_intl', 'pc105', '', ''                    ],
            # Translators: the word before the bar is just context and
            # doesn't need to be translated. Only after will be translated.
            'us'                      : [gkn(_('keyboard|U.S. English')), 'us', 'pc105', '', ''                               ],
            }


def get_supported_models():
    models = KeyboardModels()
    maps = models.modelDict.keys()
    maps.sort()
    for map in maps:
        print map
